# MapAttributesQuestionLoginInfo

The information about the user collected from the authentication system used to build the attribute mapping. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**user_object** | [**UserSummary**](UserSummary.md) |  | 
**client_guid** | **str** | The guid of the client initiating the request on behalf of the user | 
**issuer_guid** | **str** | The guid of the issuer the user is logging into. | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


